"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import pricefeed.params_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the pricefeed module's genesis state."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PARAMS_FIELD_NUMBER: builtins.int
    POSTED_PRICES_FIELD_NUMBER: builtins.int
    GENESIS_ORACLES_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> pricefeed.params_pb2.Params:
        """params defines all the paramaters of the module."""
        pass
    @property
    def posted_prices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[pricefeed.params_pb2.PostedPrice]: ...
    @property
    def genesis_oracles(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        params: typing.Optional[pricefeed.params_pb2.Params] = ...,
        posted_prices: typing.Optional[typing.Iterable[pricefeed.params_pb2.PostedPrice]] = ...,
        genesis_oracles: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params",b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["genesis_oracles",b"genesis_oracles","params",b"params","posted_prices",b"posted_prices"]) -> None: ...
global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import dex.v1.pool_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgCreatePool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CREATOR_FIELD_NUMBER: builtins.int
    POOLPARAMS_FIELD_NUMBER: builtins.int
    POOLASSETS_FIELD_NUMBER: builtins.int
    creator: typing.Text
    @property
    def poolParams(self) -> dex.v1.pool_pb2.PoolParams: ...
    @property
    def poolAssets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[dex.v1.pool_pb2.PoolAsset]: ...
    def __init__(self,
        *,
        creator: typing.Text = ...,
        poolParams: typing.Optional[dex.v1.pool_pb2.PoolParams] = ...,
        poolAssets: typing.Optional[typing.Iterable[dex.v1.pool_pb2.PoolAsset]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["poolParams",b"poolParams"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creator",b"creator","poolAssets",b"poolAssets","poolParams",b"poolParams"]) -> None: ...
global___MsgCreatePool = MsgCreatePool

class MsgCreatePoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POOLID_FIELD_NUMBER: builtins.int
    poolId: builtins.int
    def __init__(self,
        *,
        poolId: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["poolId",b"poolId"]) -> None: ...
global___MsgCreatePoolResponse = MsgCreatePoolResponse

class MsgJoinPool(google.protobuf.message.Message):
    """
    Message to join a pool (identified by poolId) with a set of tokens to deposit.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    POOLID_FIELD_NUMBER: builtins.int
    TOKENSIN_FIELD_NUMBER: builtins.int
    sender: typing.Text
    poolId: builtins.int
    @property
    def tokensIn(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        sender: typing.Text = ...,
        poolId: builtins.int = ...,
        tokensIn: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["poolId",b"poolId","sender",b"sender","tokensIn",b"tokensIn"]) -> None: ...
global___MsgJoinPool = MsgJoinPool

class MsgJoinPoolResponse(google.protobuf.message.Message):
    """
    Response when a user joins a pool.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    POOL_FIELD_NUMBER: builtins.int
    NUMPOOLSHARESOUT_FIELD_NUMBER: builtins.int
    REMAININGCOINS_FIELD_NUMBER: builtins.int
    @property
    def pool(self) -> dex.v1.pool_pb2.Pool:
        """the final state of the pool after a join"""
        pass
    @property
    def numPoolSharesOut(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """sum of LP tokens minted from the join"""
        pass
    @property
    def remainingCoins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]:
        """remaining tokens from attempting to join the pool"""
        pass
    def __init__(self,
        *,
        pool: typing.Optional[dex.v1.pool_pb2.Pool] = ...,
        numPoolSharesOut: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        remainingCoins: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["numPoolSharesOut",b"numPoolSharesOut","pool",b"pool"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["numPoolSharesOut",b"numPoolSharesOut","pool",b"pool","remainingCoins",b"remainingCoins"]) -> None: ...
global___MsgJoinPoolResponse = MsgJoinPoolResponse

class MsgExitPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    POOLID_FIELD_NUMBER: builtins.int
    POOLSHARES_FIELD_NUMBER: builtins.int
    sender: typing.Text
    poolId: builtins.int
    @property
    def poolShares(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        sender: typing.Text = ...,
        poolId: builtins.int = ...,
        poolShares: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["poolShares",b"poolShares"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["poolId",b"poolId","poolShares",b"poolShares","sender",b"sender"]) -> None: ...
global___MsgExitPool = MsgExitPool

class MsgExitPoolResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKENSOUT_FIELD_NUMBER: builtins.int
    @property
    def tokensOut(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        tokensOut: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tokensOut",b"tokensOut"]) -> None: ...
global___MsgExitPoolResponse = MsgExitPoolResponse

class MsgSwapAssets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SENDER_FIELD_NUMBER: builtins.int
    POOLID_FIELD_NUMBER: builtins.int
    TOKENIN_FIELD_NUMBER: builtins.int
    TOKENOUTDENOM_FIELD_NUMBER: builtins.int
    sender: typing.Text
    poolId: builtins.int
    @property
    def tokenIn(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    tokenOutDenom: typing.Text
    def __init__(self,
        *,
        sender: typing.Text = ...,
        poolId: builtins.int = ...,
        tokenIn: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        tokenOutDenom: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tokenIn",b"tokenIn"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["poolId",b"poolId","sender",b"sender","tokenIn",b"tokenIn","tokenOutDenom",b"tokenOutDenom"]) -> None: ...
global___MsgSwapAssets = MsgSwapAssets

class MsgSwapAssetsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKENOUT_FIELD_NUMBER: builtins.int
    @property
    def tokenOut(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        tokenOut: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tokenOut",b"tokenOut"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tokenOut",b"tokenOut"]) -> None: ...
global___MsgSwapAssetsResponse = MsgSwapAssetsResponse

class EventPoolJoined(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKENS_IN_FIELD_NUMBER: builtins.int
    POOL_SHARES_OUT_FIELD_NUMBER: builtins.int
    REM_COINS_FIELD_NUMBER: builtins.int
    address: typing.Text
    pool_id: builtins.int
    @property
    def tokens_in(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    @property
    def pool_shares_out(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def rem_coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        address: typing.Text = ...,
        pool_id: builtins.int = ...,
        tokens_in: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        pool_shares_out: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        rem_coins: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool_shares_out",b"pool_shares_out"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","pool_id",b"pool_id","pool_shares_out",b"pool_shares_out","rem_coins",b"rem_coins","tokens_in",b"tokens_in"]) -> None: ...
global___EventPoolJoined = EventPoolJoined

class EventPoolCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CREATOR_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    creator: typing.Text
    pool_id: builtins.int
    def __init__(self,
        *,
        creator: typing.Text = ...,
        pool_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["creator",b"creator","pool_id",b"pool_id"]) -> None: ...
global___EventPoolCreated = EventPoolCreated

class EventPoolExited(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    POOL_SHARES_IN_FIELD_NUMBER: builtins.int
    TOKENS_OUT_FIELD_NUMBER: builtins.int
    address: typing.Text
    pool_id: builtins.int
    @property
    def pool_shares_in(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def tokens_out(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        address: typing.Text = ...,
        pool_id: builtins.int = ...,
        pool_shares_in: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        tokens_out: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pool_shares_in",b"pool_shares_in"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","pool_id",b"pool_id","pool_shares_in",b"pool_shares_in","tokens_out",b"tokens_out"]) -> None: ...
global___EventPoolExited = EventPoolExited

class EventAssetsSwapped(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    POOL_ID_FIELD_NUMBER: builtins.int
    TOKEN_IN_FIELD_NUMBER: builtins.int
    TOKEN_OUT_FIELD_NUMBER: builtins.int
    address: typing.Text
    pool_id: builtins.int
    @property
    def token_in(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def token_out(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    def __init__(self,
        *,
        address: typing.Text = ...,
        pool_id: builtins.int = ...,
        token_in: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        token_out: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token_in",b"token_in","token_out",b"token_out"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","pool_id",b"pool_id","token_in",b"token_in","token_out",b"token_out"]) -> None: ...
global___EventAssetsSwapped = EventAssetsSwapped



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lockup/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from lockup.v1 import lock_pb2 as lockup_dot_v1_dot_lock__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12lockup/v1/tx.proto\x12\x10nibiru.lockup.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x14lockup/v1/lock.proto\x1a\x1cgoogle/api/annotations.proto\"\xec\x01\n\rMsgLockTokens\x12\x1f\n\x05owner\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12^\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"(\n\x15MsgLockTokensResponse\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\"3\n\x11MsgInitiateUnlock\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07lock_id\x18\x02 \x01(\x04\"\x1b\n\x19MsgInitiateUnlockResponse\"+\n\tMsgUnlock\x12\r\n\x05owner\x18\x01 \x01(\t\x12\x0f\n\x07lock_id\x18\x02 \x01(\x04\"\x13\n\x11MsgUnlockResponse\"\xe7\x01\n\tEventLock\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12^\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12Z\n\x05\x63oins\x18\x04 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\xe1\x01\n\x14\x45ventUnlockInitiated\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12M\n\x0cunlocking_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1b\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"end_time\"\"\x89\x01\n\x0b\x45ventUnlock\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\r\n\x05owner\x18\x02 \x01(\t\x12Z\n\x05\x63oins\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins2\xd8\x02\n\x03Msg\x12z\n\nLockTokens\x12\x1f.nibiru.lockup.v1.MsgLockTokens\x1a\'.nibiru.lockup.v1.MsgLockTokensResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/lockup/lock_tokens\x12\x86\x01\n\x0eInitiateUnlock\x12#.nibiru.lockup.v1.MsgInitiateUnlock\x1a+.nibiru.lockup.v1.MsgInitiateUnlockResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/nibiru/lockup/init_unlock\x12L\n\x06Unlock\x12\x1b.nibiru.lockup.v1.MsgUnlock\x1a#.nibiru.lockup.v1.MsgUnlockResponse\"\x00\x42.Z,github.com/NibiruChain/nibiru/x/lockup/typesb\x06proto3')



_MSGLOCKTOKENS = DESCRIPTOR.message_types_by_name['MsgLockTokens']
_MSGLOCKTOKENSRESPONSE = DESCRIPTOR.message_types_by_name['MsgLockTokensResponse']
_MSGINITIATEUNLOCK = DESCRIPTOR.message_types_by_name['MsgInitiateUnlock']
_MSGINITIATEUNLOCKRESPONSE = DESCRIPTOR.message_types_by_name['MsgInitiateUnlockResponse']
_MSGUNLOCK = DESCRIPTOR.message_types_by_name['MsgUnlock']
_MSGUNLOCKRESPONSE = DESCRIPTOR.message_types_by_name['MsgUnlockResponse']
_EVENTLOCK = DESCRIPTOR.message_types_by_name['EventLock']
_EVENTUNLOCKINITIATED = DESCRIPTOR.message_types_by_name['EventUnlockInitiated']
_EVENTUNLOCK = DESCRIPTOR.message_types_by_name['EventUnlock']
MsgLockTokens = _reflection.GeneratedProtocolMessageType('MsgLockTokens', (_message.Message,), {
  'DESCRIPTOR' : _MSGLOCKTOKENS,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgLockTokens)
  })
_sym_db.RegisterMessage(MsgLockTokens)

MsgLockTokensResponse = _reflection.GeneratedProtocolMessageType('MsgLockTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGLOCKTOKENSRESPONSE,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgLockTokensResponse)
  })
_sym_db.RegisterMessage(MsgLockTokensResponse)

MsgInitiateUnlock = _reflection.GeneratedProtocolMessageType('MsgInitiateUnlock', (_message.Message,), {
  'DESCRIPTOR' : _MSGINITIATEUNLOCK,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgInitiateUnlock)
  })
_sym_db.RegisterMessage(MsgInitiateUnlock)

MsgInitiateUnlockResponse = _reflection.GeneratedProtocolMessageType('MsgInitiateUnlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGINITIATEUNLOCKRESPONSE,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgInitiateUnlockResponse)
  })
_sym_db.RegisterMessage(MsgInitiateUnlockResponse)

MsgUnlock = _reflection.GeneratedProtocolMessageType('MsgUnlock', (_message.Message,), {
  'DESCRIPTOR' : _MSGUNLOCK,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgUnlock)
  })
_sym_db.RegisterMessage(MsgUnlock)

MsgUnlockResponse = _reflection.GeneratedProtocolMessageType('MsgUnlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGUNLOCKRESPONSE,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.MsgUnlockResponse)
  })
_sym_db.RegisterMessage(MsgUnlockResponse)

EventLock = _reflection.GeneratedProtocolMessageType('EventLock', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLOCK,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.EventLock)
  })
_sym_db.RegisterMessage(EventLock)

EventUnlockInitiated = _reflection.GeneratedProtocolMessageType('EventUnlockInitiated', (_message.Message,), {
  'DESCRIPTOR' : _EVENTUNLOCKINITIATED,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.EventUnlockInitiated)
  })
_sym_db.RegisterMessage(EventUnlockInitiated)

EventUnlock = _reflection.GeneratedProtocolMessageType('EventUnlock', (_message.Message,), {
  'DESCRIPTOR' : _EVENTUNLOCK,
  '__module__' : 'lockup.v1.tx_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.EventUnlock)
  })
_sym_db.RegisterMessage(EventUnlock)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/lockup/types'
  _MSGLOCKTOKENS.fields_by_name['owner']._options = None
  _MSGLOCKTOKENS.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
  _MSGLOCKTOKENS.fields_by_name['duration']._options = None
  _MSGLOCKTOKENS.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _MSGLOCKTOKENS.fields_by_name['coins']._options = None
  _MSGLOCKTOKENS.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _EVENTLOCK.fields_by_name['duration']._options = None
  _EVENTLOCK.fields_by_name['duration']._serialized_options = b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
  _EVENTLOCK.fields_by_name['coins']._options = None
  _EVENTLOCK.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _EVENTUNLOCKINITIATED.fields_by_name['coins']._options = None
  _EVENTUNLOCKINITIATED.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _EVENTUNLOCKINITIATED.fields_by_name['unlocking_at']._options = None
  _EVENTUNLOCKINITIATED.fields_by_name['unlocking_at']._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\017yaml:\"end_time\"'
  _EVENTUNLOCK.fields_by_name['coins']._options = None
  _EVENTUNLOCK.fields_by_name['coins']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSG.methods_by_name['LockTokens']._options = None
  _MSG.methods_by_name['LockTokens']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/lockup/lock_tokens'
  _MSG.methods_by_name['InitiateUnlock']._options = None
  _MSG.methods_by_name['InitiateUnlock']._serialized_options = b'\202\323\344\223\002\034\"\032/nibiru/lockup/init_unlock'
  _MSGLOCKTOKENS._serialized_start=212
  _MSGLOCKTOKENS._serialized_end=448
  _MSGLOCKTOKENSRESPONSE._serialized_start=450
  _MSGLOCKTOKENSRESPONSE._serialized_end=490
  _MSGINITIATEUNLOCK._serialized_start=492
  _MSGINITIATEUNLOCK._serialized_end=543
  _MSGINITIATEUNLOCKRESPONSE._serialized_start=545
  _MSGINITIATEUNLOCKRESPONSE._serialized_end=572
  _MSGUNLOCK._serialized_start=574
  _MSGUNLOCK._serialized_end=617
  _MSGUNLOCKRESPONSE._serialized_start=619
  _MSGUNLOCKRESPONSE._serialized_end=638
  _EVENTLOCK._serialized_start=641
  _EVENTLOCK._serialized_end=872
  _EVENTUNLOCKINITIATED._serialized_start=875
  _EVENTUNLOCKINITIATED._serialized_end=1100
  _EVENTUNLOCK._serialized_start=1103
  _EVENTUNLOCK._serialized_end=1240
  _MSG._serialized_start=1243
  _MSG._serialized_end=1587
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.authz.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the authz Msg service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    Grant: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.tx_pb2.MsgGrant,
        cosmos.authz.v1beta1.tx_pb2.MsgGrantResponse]
    """Grant grants the provided authorization to the grantee on the granter's
    account with the provided expiration time. If there is already a grant
    for the given (granter, grantee, Authorization) triple, then the grant
    will be overwritten.
    """

    Exec: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.tx_pb2.MsgExec,
        cosmos.authz.v1beta1.tx_pb2.MsgExecResponse]
    """Exec attempts to execute the provided messages using
    authorizations granted to the grantee. Each message should have only
    one signer corresponding to the granter of the authorization.
    """

    Revoke: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.tx_pb2.MsgRevoke,
        cosmos.authz.v1beta1.tx_pb2.MsgRevokeResponse]
    """Revoke revokes any authorization corresponding to the provided method name on the
    granter's account that has been granted to the grantee.
    """


class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the authz Msg service."""
    @abc.abstractmethod
    def Grant(self,
        request: cosmos.authz.v1beta1.tx_pb2.MsgGrant,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.tx_pb2.MsgGrantResponse:
        """Grant grants the provided authorization to the grantee on the granter's
        account with the provided expiration time. If there is already a grant
        for the given (granter, grantee, Authorization) triple, then the grant
        will be overwritten.
        """
        pass

    @abc.abstractmethod
    def Exec(self,
        request: cosmos.authz.v1beta1.tx_pb2.MsgExec,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.tx_pb2.MsgExecResponse:
        """Exec attempts to execute the provided messages using
        authorizations granted to the grantee. Each message should have only
        one signer corresponding to the granter of the authorization.
        """
        pass

    @abc.abstractmethod
    def Revoke(self,
        request: cosmos.authz.v1beta1.tx_pb2.MsgRevoke,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.tx_pb2.MsgRevokeResponse:
        """Revoke revokes any authorization corresponding to the provided method name on the
        granter's account that has been granted to the grantee.
        """
        pass


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import perp.v1.query_pb2

class QueryStub:
    """Query defines the gRPC querier service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    Params: grpc.UnaryUnaryMultiCallable[
        perp.v1.query_pb2.QueryParamsRequest,
        perp.v1.query_pb2.QueryParamsResponse]
    """Parameters queries the parameters of the x/perp module."""

    TraderPosition: grpc.UnaryUnaryMultiCallable[
        perp.v1.query_pb2.QueryTraderPositionRequest,
        perp.v1.query_pb2.QueryTraderPositionResponse]


class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""
    @abc.abstractmethod
    def Params(self,
        request: perp.v1.query_pb2.QueryParamsRequest,
        context: grpc.ServicerContext,
    ) -> perp.v1.query_pb2.QueryParamsResponse:
        """Parameters queries the parameters of the x/perp module."""
        pass

    @abc.abstractmethod
    def TraderPosition(self,
        request: perp.v1.query_pb2.QueryTraderPositionRequest,
        context: grpc.ServicerContext,
    ) -> perp.v1.query_pb2.QueryTraderPositionResponse: ...


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PoolParams(google.protobuf.message.Message):
    """Configuration parameters for the pool."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SWAPFEE_FIELD_NUMBER: builtins.int
    EXITFEE_FIELD_NUMBER: builtins.int
    swapFee: typing.Text
    exitFee: typing.Text
    def __init__(self,
        *,
        swapFee: typing.Text = ...,
        exitFee: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exitFee",b"exitFee","swapFee",b"swapFee"]) -> None: ...
global___PoolParams = PoolParams

class PoolAsset(google.protobuf.message.Message):
    """Which assets the pool contains."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOKEN_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def token(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """Coins we are talking about,
        the denomination must be unique amongst all PoolAssets for this pool.
        """
        pass
    weight: typing.Text
    """Weight that is not normalized. This weight must be less than 2^50"""

    def __init__(self,
        *,
        token: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        weight: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["token",b"token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["token",b"token","weight",b"weight"]) -> None: ...
global___PoolAsset = PoolAsset

class Pool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    POOLPARAMS_FIELD_NUMBER: builtins.int
    POOLASSETS_FIELD_NUMBER: builtins.int
    TOTALWEIGHT_FIELD_NUMBER: builtins.int
    TOTALSHARES_FIELD_NUMBER: builtins.int
    id: builtins.int
    """The pool id."""

    address: typing.Text
    """The pool account address."""

    @property
    def poolParams(self) -> global___PoolParams:
        """Fees and other pool-specific parameters."""
        pass
    @property
    def poolAssets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PoolAsset]:
        """These are assumed to be sorted by denomiation.
        They contain the pool asset and the information about the weight
        """
        pass
    totalWeight: typing.Text
    """sum of all non-normalized pool weights"""

    @property
    def totalShares(self) -> cosmos.base.v1beta1.coin_pb2.Coin:
        """sum of all LP tokens sent out"""
        pass
    def __init__(self,
        *,
        id: builtins.int = ...,
        address: typing.Text = ...,
        poolParams: typing.Optional[global___PoolParams] = ...,
        poolAssets: typing.Optional[typing.Iterable[global___PoolAsset]] = ...,
        totalWeight: typing.Text = ...,
        totalShares: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["poolParams",b"poolParams","totalShares",b"totalShares"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","id",b"id","poolAssets",b"poolAssets","poolParams",b"poolParams","totalShares",b"totalShares","totalWeight",b"totalWeight"]) -> None: ...
global___Pool = Pool



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.query.v1beta1.pagination_pb2
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import lockup.v1.lock_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryLockedCoinsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    address: typing.Text
    def __init__(self,
        *,
        address: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address"]) -> None: ...
global___QueryLockedCoinsRequest = QueryLockedCoinsRequest

class QueryLockedCoinsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LOCKED_COINS_FIELD_NUMBER: builtins.int
    @property
    def locked_coins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        locked_coins: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["locked_coins",b"locked_coins"]) -> None: ...
global___QueryLockedCoinsResponse = QueryLockedCoinsResponse

class QueryLockRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    id: builtins.int
    def __init__(self,
        *,
        id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id"]) -> None: ...
global___QueryLockRequest = QueryLockRequest

class QueryLockResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LOCK_FIELD_NUMBER: builtins.int
    @property
    def lock(self) -> lockup.v1.lock_pb2.Lock: ...
    def __init__(self,
        *,
        lock: typing.Optional[lockup.v1.lock_pb2.Lock] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["lock",b"lock"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["lock",b"lock"]) -> None: ...
global___QueryLockResponse = QueryLockResponse

class QueryLocksByAddress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ADDRESS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    address: typing.Text
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest: ...
    def __init__(self,
        *,
        address: typing.Text = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address",b"address","pagination",b"pagination"]) -> None: ...
global___QueryLocksByAddress = QueryLocksByAddress

class QueryLocksByAddressResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LOCKS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def locks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[lockup.v1.lock_pb2.Lock]: ...
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse: ...
    def __init__(self,
        *,
        locks: typing.Optional[typing.Iterable[lockup.v1.lock_pb2.Lock]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["locks",b"locks","pagination",b"pagination"]) -> None: ...
global___QueryLocksByAddressResponse = QueryLocksByAddressResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import perp.v1.tx_pb2

class MsgStub:
    """Msg defines the x/perp Msg service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    RemoveMargin: grpc.UnaryUnaryMultiCallable[
        perp.v1.tx_pb2.MsgRemoveMargin,
        perp.v1.tx_pb2.MsgRemoveMarginResponse]

    AddMargin: grpc.UnaryUnaryMultiCallable[
        perp.v1.tx_pb2.MsgAddMargin,
        perp.v1.tx_pb2.MsgAddMarginResponse]

    Liquidate: grpc.UnaryUnaryMultiCallable[
        perp.v1.tx_pb2.MsgLiquidate,
        perp.v1.tx_pb2.MsgLiquidateResponse]
    """Liquidate is a transaction that allows the caller to fully or partially 
    liquidate an existing position.
    """

    OpenPosition: grpc.UnaryUnaryMultiCallable[
        perp.v1.tx_pb2.MsgOpenPosition,
        perp.v1.tx_pb2.MsgOpenPositionResponse]

    ClosePosition: grpc.UnaryUnaryMultiCallable[
        perp.v1.tx_pb2.MsgClosePosition,
        perp.v1.tx_pb2.MsgClosePositionResponse]


class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the x/perp Msg service."""
    @abc.abstractmethod
    def RemoveMargin(self,
        request: perp.v1.tx_pb2.MsgRemoveMargin,
        context: grpc.ServicerContext,
    ) -> perp.v1.tx_pb2.MsgRemoveMarginResponse: ...

    @abc.abstractmethod
    def AddMargin(self,
        request: perp.v1.tx_pb2.MsgAddMargin,
        context: grpc.ServicerContext,
    ) -> perp.v1.tx_pb2.MsgAddMarginResponse: ...

    @abc.abstractmethod
    def Liquidate(self,
        request: perp.v1.tx_pb2.MsgLiquidate,
        context: grpc.ServicerContext,
    ) -> perp.v1.tx_pb2.MsgLiquidateResponse:
        """Liquidate is a transaction that allows the caller to fully or partially 
        liquidate an existing position.
        """
        pass

    @abc.abstractmethod
    def OpenPosition(self,
        request: perp.v1.tx_pb2.MsgOpenPosition,
        context: grpc.ServicerContext,
    ) -> perp.v1.tx_pb2.MsgOpenPositionResponse: ...

    @abc.abstractmethod
    def ClosePosition(self,
        request: perp.v1.tx_pb2.MsgClosePosition,
        context: grpc.ServicerContext,
    ) -> perp.v1.tx_pb2.MsgClosePositionResponse: ...


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.authz.v1beta1.authz_pb2
import cosmos.base.query.v1beta1.pagination_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class QueryGrantsRequest(google.protobuf.message.Message):
    """QueryGrantsRequest is the request type for the Query/Grants RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    MSG_TYPE_URL_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    granter: typing.Text
    grantee: typing.Text
    msg_type_url: typing.Text
    """Optional, msg_type_url, when set, will query only grants matching given msg type."""

    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
        pass
    def __init__(self,
        *,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        msg_type_url: typing.Text = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee",b"grantee","granter",b"granter","msg_type_url",b"msg_type_url","pagination",b"pagination"]) -> None: ...
global___QueryGrantsRequest = QueryGrantsRequest

class QueryGrantsResponse(google.protobuf.message.Message):
    """QueryGrantsResponse is the response type for the Query/Authorizations RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.authz.v1beta1.authz_pb2.Grant]:
        """authorizations is a list of grants granted for grantee by granter."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
        pass
    def __init__(self,
        *,
        grants: typing.Optional[typing.Iterable[cosmos.authz.v1beta1.authz_pb2.Grant]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grants",b"grants","pagination",b"pagination"]) -> None: ...
global___QueryGrantsResponse = QueryGrantsResponse

class QueryGranterGrantsRequest(google.protobuf.message.Message):
    """QueryGranterGrantsRequest is the request type for the Query/GranterGrants RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTER_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    granter: typing.Text
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
        pass
    def __init__(self,
        *,
        granter: typing.Text = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["granter",b"granter","pagination",b"pagination"]) -> None: ...
global___QueryGranterGrantsRequest = QueryGranterGrantsRequest

class QueryGranterGrantsResponse(google.protobuf.message.Message):
    """QueryGranterGrantsResponse is the response type for the Query/GranterGrants RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.authz.v1beta1.authz_pb2.GrantAuthorization]:
        """grants is a list of grants granted by the granter."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
        pass
    def __init__(self,
        *,
        grants: typing.Optional[typing.Iterable[cosmos.authz.v1beta1.authz_pb2.GrantAuthorization]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grants",b"grants","pagination",b"pagination"]) -> None: ...
global___QueryGranterGrantsResponse = QueryGranterGrantsResponse

class QueryGranteeGrantsRequest(google.protobuf.message.Message):
    """QueryGranteeGrantsRequest is the request type for the Query/IssuedGrants RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTEE_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    grantee: typing.Text
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageRequest:
        """pagination defines an pagination for the request."""
        pass
    def __init__(self,
        *,
        grantee: typing.Text = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageRequest] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grantee",b"grantee","pagination",b"pagination"]) -> None: ...
global___QueryGranteeGrantsRequest = QueryGranteeGrantsRequest

class QueryGranteeGrantsResponse(google.protobuf.message.Message):
    """QueryGranteeGrantsResponse is the response type for the Query/GranteeGrants RPC method."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTS_FIELD_NUMBER: builtins.int
    PAGINATION_FIELD_NUMBER: builtins.int
    @property
    def grants(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.authz.v1beta1.authz_pb2.GrantAuthorization]:
        """grants is a list of grants granted to the grantee."""
        pass
    @property
    def pagination(self) -> cosmos.base.query.v1beta1.pagination_pb2.PageResponse:
        """pagination defines an pagination for the response."""
        pass
    def __init__(self,
        *,
        grants: typing.Optional[typing.Iterable[cosmos.authz.v1beta1.authz_pb2.GrantAuthorization]] = ...,
        pagination: typing.Optional[cosmos.base.query.v1beta1.pagination_pb2.PageResponse] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pagination",b"pagination"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["grants",b"grants","pagination",b"pagination"]) -> None: ...
global___QueryGranteeGrantsResponse = QueryGranteeGrantsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ListAllInterfacesRequest(google.protobuf.message.Message):
    """ListAllInterfacesRequest is the request type of the ListAllInterfaces RPC."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___ListAllInterfacesRequest = ListAllInterfacesRequest

class ListAllInterfacesResponse(google.protobuf.message.Message):
    """ListAllInterfacesResponse is the response type of the ListAllInterfaces RPC."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_NAMES_FIELD_NUMBER: builtins.int
    @property
    def interface_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """interface_names is an array of all the registered interfaces."""
        pass
    def __init__(self,
        *,
        interface_names: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_names",b"interface_names"]) -> None: ...
global___ListAllInterfacesResponse = ListAllInterfacesResponse

class ListImplementationsRequest(google.protobuf.message.Message):
    """ListImplementationsRequest is the request type of the ListImplementations
    RPC.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INTERFACE_NAME_FIELD_NUMBER: builtins.int
    interface_name: typing.Text
    """interface_name defines the interface to query the implementations for."""

    def __init__(self,
        *,
        interface_name: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["interface_name",b"interface_name"]) -> None: ...
global___ListImplementationsRequest = ListImplementationsRequest

class ListImplementationsResponse(google.protobuf.message.Message):
    """ListImplementationsResponse is the response type of the ListImplementations
    RPC.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    IMPLEMENTATION_MESSAGE_NAMES_FIELD_NUMBER: builtins.int
    @property
    def implementation_message_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]: ...
    def __init__(self,
        *,
        implementation_message_names: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["implementation_message_names",b"implementation_message_names"]) -> None: ...
global___ListImplementationsResponse = ListImplementationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgPostPrice(google.protobuf.message.Message):
    """MsgPostPrice represents a method for creating a new post price"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    FROM_FIELD_NUMBER: builtins.int
    TOKEN0_FIELD_NUMBER: builtins.int
    TOKEN1_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    token0: typing.Text
    """Token0: denominator unit of the price, a.k.a. quote asset"""

    token1: typing.Text
    """Token1: numerator unit of price, a.k.a. base asset"""

    price: typing.Text
    """Price: Price of the trading pair in units of token1 / token0."""

    @property
    def expiry(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        token0: typing.Text = ...,
        token1: typing.Text = ...,
        price: typing.Text = ...,
        expiry: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiry",b"expiry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiry",b"expiry","from",b"from","price",b"price","token0",b"token0","token1",b"token1"]) -> None: ...
global___MsgPostPrice = MsgPostPrice

class MsgPostPriceResponse(google.protobuf.message.Message):
    """MsgPostPriceResponse defines the Msg/PostPrice response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgPostPriceResponse = MsgPostPriceResponse

class EventOracleUpdatePrice(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    ORACLE_FIELD_NUMBER: builtins.int
    PAIR_PRICE_FIELD_NUMBER: builtins.int
    EXPIRY_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    oracle: typing.Text
    pair_price: typing.Text
    @property
    def expiry(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        oracle: typing.Text = ...,
        pair_price: typing.Text = ...,
        expiry: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiry",b"expiry"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expiry",b"expiry","oracle",b"oracle","pair_id",b"pair_id","pair_price",b"pair_price"]) -> None: ...
global___EventOracleUpdatePrice = EventOracleUpdatePrice

class EventPairPriceUpdated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    PAIR_PRICE_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    pair_price: typing.Text
    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        pair_price: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair_id",b"pair_id","pair_price",b"pair_price"]) -> None: ...
global___EventPairPriceUpdated = EventPairPriceUpdated



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.authz.v1beta1.query_pb2
import grpc

class QueryStub:
    """Query defines the gRPC querier service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    Grants: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.query_pb2.QueryGrantsRequest,
        cosmos.authz.v1beta1.query_pb2.QueryGrantsResponse]
    """Returns list of `Authorization`, granted to the grantee by the granter."""

    GranterGrants: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.query_pb2.QueryGranterGrantsRequest,
        cosmos.authz.v1beta1.query_pb2.QueryGranterGrantsResponse]
    """GranterGrants returns list of `GrantAuthorization`, granted by granter.

    Since: cosmos-sdk 0.45.2
    """

    GranteeGrants: grpc.UnaryUnaryMultiCallable[
        cosmos.authz.v1beta1.query_pb2.QueryGranteeGrantsRequest,
        cosmos.authz.v1beta1.query_pb2.QueryGranteeGrantsResponse]
    """GranteeGrants returns a list of `GrantAuthorization` by grantee.

    Since: cosmos-sdk 0.45.2
    """


class QueryServicer(metaclass=abc.ABCMeta):
    """Query defines the gRPC querier service."""
    @abc.abstractmethod
    def Grants(self,
        request: cosmos.authz.v1beta1.query_pb2.QueryGrantsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.query_pb2.QueryGrantsResponse:
        """Returns list of `Authorization`, granted to the grantee by the granter."""
        pass

    @abc.abstractmethod
    def GranterGrants(self,
        request: cosmos.authz.v1beta1.query_pb2.QueryGranterGrantsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.query_pb2.QueryGranterGrantsResponse:
        """GranterGrants returns list of `GrantAuthorization`, granted by granter.

        Since: cosmos-sdk 0.45.2
        """
        pass

    @abc.abstractmethod
    def GranteeGrants(self,
        request: cosmos.authz.v1beta1.query_pb2.QueryGranteeGrantsRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.authz.v1beta1.query_pb2.QueryGranteeGrantsResponse:
        """GranteeGrants returns a list of `GrantAuthorization` by grantee.

        Since: cosmos-sdk 0.45.2
        """
        pass


def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import cosmos.gov.v1beta1.gov_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgSubmitProposal(google.protobuf.message.Message):
    """MsgSubmitProposal defines an sdk.Msg type that supports submitting arbitrary
    proposal Content.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    INITIAL_DEPOSIT_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def initial_deposit(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    proposer: typing.Text
    def __init__(self,
        *,
        content: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        initial_deposit: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        proposer: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","initial_deposit",b"initial_deposit","proposer",b"proposer"]) -> None: ...
global___MsgSubmitProposal = MsgSubmitProposal

class MsgSubmitProposalResponse(google.protobuf.message.Message):
    """MsgSubmitProposalResponse defines the Msg/SubmitProposal response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposal_id",b"proposal_id"]) -> None: ...
global___MsgSubmitProposalResponse = MsgSubmitProposalResponse

class MsgVote(google.protobuf.message.Message):
    """MsgVote defines a message to cast a vote."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: typing.Text
    option: cosmos.gov.v1beta1.gov_pb2.VoteOption.ValueType
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        voter: typing.Text = ...,
        option: cosmos.gov.v1beta1.gov_pb2.VoteOption.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["option",b"option","proposal_id",b"proposal_id","voter",b"voter"]) -> None: ...
global___MsgVote = MsgVote

class MsgVoteResponse(google.protobuf.message.Message):
    """MsgVoteResponse defines the Msg/Vote response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgVoteResponse = MsgVoteResponse

class MsgVoteWeighted(google.protobuf.message.Message):
    """MsgVoteWeighted defines a message to cast a vote.

    Since: cosmos-sdk 0.43
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    VOTER_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    voter: typing.Text
    @property
    def options(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.gov.v1beta1.gov_pb2.WeightedVoteOption]: ...
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        voter: typing.Text = ...,
        options: typing.Optional[typing.Iterable[cosmos.gov.v1beta1.gov_pb2.WeightedVoteOption]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["options",b"options","proposal_id",b"proposal_id","voter",b"voter"]) -> None: ...
global___MsgVoteWeighted = MsgVoteWeighted

class MsgVoteWeightedResponse(google.protobuf.message.Message):
    """MsgVoteWeightedResponse defines the Msg/VoteWeighted response type.

    Since: cosmos-sdk 0.43
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgVoteWeightedResponse = MsgVoteWeightedResponse

class MsgDeposit(google.protobuf.message.Message):
    """MsgDeposit defines a message to submit a deposit to an existing proposal."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PROPOSAL_ID_FIELD_NUMBER: builtins.int
    DEPOSITOR_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    proposal_id: builtins.int
    depositor: typing.Text
    @property
    def amount(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[cosmos.base.v1beta1.coin_pb2.Coin]: ...
    def __init__(self,
        *,
        proposal_id: builtins.int = ...,
        depositor: typing.Text = ...,
        amount: typing.Optional[typing.Iterable[cosmos.base.v1beta1.coin_pb2.Coin]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount","depositor",b"depositor","proposal_id",b"proposal_id"]) -> None: ...
global___MsgDeposit = MsgDeposit

class MsgDepositResponse(google.protobuf.message.Message):
    """MsgDepositResponse defines the Msg/Deposit response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgDepositResponse = MsgDepositResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dex/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from dex.v1 import params_pb2 as dex_dot_v1_dot_params__pb2
from dex.v1 import pool_pb2 as dex_dot_v1_dot_pool__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x64\x65x/v1/query.proto\x12\rnibiru.dex.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x13\x64\x65x/v1/params.proto\x1a\x11\x64\x65x/v1/pool.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x14\n\x12QueryParamsRequest\"B\n\x13QueryParamsResponse\x12+\n\x06params\x18\x01 \x01(\x0b\x32\x15.nibiru.dex.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x18\n\x16QueryPoolNumberRequest\")\n\x17QueryPoolNumberResponse\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"\"\n\x10QueryPoolRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"6\n\x11QueryPoolResponse\x12!\n\x04pool\x18\x01 \x01(\x0b\x32\x13.nibiru.dex.v1.Pool\"O\n\x11QueryPoolsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"u\n\x12QueryPoolsResponse\x12\"\n\x05pools\x18\x01 \x03(\x0b\x32\x13.nibiru.dex.v1.Pool\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"(\n\x16QueryPoolParamsRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"H\n\x17QueryPoolParamsResponse\x12-\n\npoolParams\x18\x01 \x01(\x0b\x32\x19.nibiru.dex.v1.PoolParams\"\x16\n\x14QueryNumPoolsRequest\")\n\x15QueryNumPoolsResponse\x12\x10\n\x08numPools\x18\x01 \x01(\x04\"\x1c\n\x1aQueryTotalLiquidityRequest\"\x91\x01\n\x1bQueryTotalLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\"0\n\x1eQueryTotalPoolLiquidityRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"\x95\x01\n\x1fQueryTotalPoolLiquidityResponse\x12r\n\tliquidity\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"liquidity\"\xc8\xde\x1f\x00\")\n\x17QueryTotalSharesRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"g\n\x18QueryTotalSharesResponse\x12K\n\x0btotalShares\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x1b\xf2\xde\x1f\x13yaml:\"total_shares\"\xc8\xde\x1f\x00\"T\n\x15QuerySpotPriceRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12\x14\n\x0ctokenInDenom\x18\x02 \x01(\t\x12\x15\n\rtokenOutDenom\x18\x03 \x01(\t\"+\n\x16QuerySpotPriceResponse\x12\x11\n\tspotPrice\x18\x01 \x01(\t\"\x8b\x01\n\x1dQuerySwapExactAmountInRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12\x43\n\x07tokenIn\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\x12\x15\n\rtokenOutDenom\x18\x03 \x01(\t\"g\n\x1eQuerySwapExactAmountInResponse\x12\x45\n\x08tokenOut\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\"\x8d\x01\n\x1eQuerySwapExactAmountOutRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12\x45\n\x08tokenOut\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x18\xf2\xde\x1f\x10yaml:\"token_out\"\xc8\xde\x1f\x00\x12\x14\n\x0ctokenInDenom\x18\x03 \x01(\t\"f\n\x1fQuerySwapExactAmountOutResponse\x12\x43\n\x07tokenIn\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x17\xf2\xde\x1f\x0fyaml:\"token_in\"\xc8\xde\x1f\x00\"\xa2\x01\n\x1dQueryJoinExactAmountInRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12q\n\x08tokensIn\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"tokens_in\"\xc8\xde\x1f\x00\"\xf4\x01\n\x1eQueryJoinExactAmountInResponse\x12_\n\rpoolSharesOut\x18\x01 \x01(\tBH\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x16yaml:\"pool_shares_out\"\xc8\xde\x1f\x00\x12q\n\x08remCoins\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBD\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x10yaml:\"rem_coins\"\xc8\xde\x1f\x00\"0\n\x1eQueryJoinExactAmountOutRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"!\n\x1fQueryJoinExactAmountOutResponse\"\x8e\x01\n\x1dQueryExitExactAmountInRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\x12]\n\x0cpoolSharesIn\x18\x02 \x01(\tBG\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xf2\xde\x1f\x15yaml:\"pool_shares_in\"\xc8\xde\x1f\x00\"\x95\x01\n\x1eQueryExitExactAmountInResponse\x12s\n\ttokensOut\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBE\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\xf2\xde\x1f\x11yaml:\"tokens_out\"\xc8\xde\x1f\x00\"0\n\x1eQueryExitExactAmountOutRequest\x12\x0e\n\x06poolId\x18\x01 \x01(\x04\"!\n\x1fQueryExitExactAmountOutResponse2\xeb\x12\n\x05Query\x12k\n\x06Params\x12!.nibiru.dex.v1.QueryParamsRequest\x1a\".nibiru.dex.v1.QueryParamsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/nibiru/dex/params\x12|\n\nPoolNumber\x12%.nibiru.dex.v1.QueryPoolNumberRequest\x1a&.nibiru.dex.v1.QueryPoolNumberResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/nibiru/dex/pool_number\x12\x63\n\x04Pool\x12\x1f.nibiru.dex.v1.QueryPoolRequest\x1a .nibiru.dex.v1.QueryPoolResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/nibiru/dex/pool\x12g\n\x05Pools\x12 .nibiru.dex.v1.QueryPoolsRequest\x1a!.nibiru.dex.v1.QueryPoolsResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/nibiru/dex/pools\x12\x86\x01\n\nPoolParams\x12%.nibiru.dex.v1.QueryPoolParamsRequest\x1a&.nibiru.dex.v1.QueryPoolParamsResponse\")\x82\xd3\xe4\x93\x02#\x12!/nibiru/dex/pools/{poolId}/params\x12t\n\x08NumPools\x12#.nibiru.dex.v1.QueryNumPoolsRequest\x1a$.nibiru.dex.v1.QueryNumPoolsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/nibiru/dex/num_pools\x12\x8c\x01\n\x0eTotalLiquidity\x12).nibiru.dex.v1.QueryTotalLiquidityRequest\x1a*.nibiru.dex.v1.QueryTotalLiquidityResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/nibiru/dex/total_liquidity\x12\xac\x01\n\x12TotalPoolLiquidity\x12-.nibiru.dex.v1.QueryTotalPoolLiquidityRequest\x1a..nibiru.dex.v1.QueryTotalPoolLiquidityResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//nibiru/dex/pools/{poolId}/total_pool_liquidity\x12\x8f\x01\n\x0bTotalShares\x12&.nibiru.dex.v1.QueryTotalSharesRequest\x1a\'.nibiru.dex.v1.QueryTotalSharesResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/nibiru/dex/pools/{poolId}/total_shares\x12\x83\x01\n\tSpotPrice\x12$.nibiru.dex.v1.QuerySpotPriceRequest\x1a%.nibiru.dex.v1.QuerySpotPriceResponse\")\x82\xd3\xe4\x93\x02#\x12!/nibiru/dex/pools/{poolId}/prices\x12\xb4\x01\n\x19\x45stimateSwapExactAmountIn\x12,.nibiru.dex.v1.QuerySwapExactAmountInRequest\x1a-.nibiru.dex.v1.QuerySwapExactAmountInResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/dex/{poolId}/estimate/swap_exact_amount_in\x12\xb8\x01\n\x1a\x45stimateSwapExactAmountOut\x12-.nibiru.dex.v1.QuerySwapExactAmountOutRequest\x1a..nibiru.dex.v1.QuerySwapExactAmountOutResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{poolId}/estimate/swap_exact_amount_out\x12\xb4\x01\n\x19\x45stimateJoinExactAmountIn\x12,.nibiru.dex.v1.QueryJoinExactAmountInRequest\x1a-.nibiru.dex.v1.QueryJoinExactAmountInResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/dex/{poolId}/estimate/join_exact_amount_in\x12\xb8\x01\n\x1a\x45stimateJoinExactAmountOut\x12-.nibiru.dex.v1.QueryJoinExactAmountOutRequest\x1a..nibiru.dex.v1.QueryJoinExactAmountOutResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{poolId}/estimate/join_exact_amount_out\x12\xb4\x01\n\x19\x45stimateExitExactAmountIn\x12,.nibiru.dex.v1.QueryExitExactAmountInRequest\x1a-.nibiru.dex.v1.QueryExitExactAmountInResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/dex/{poolId}/estimate/exit_exact_amount_in\x12\xb8\x01\n\x1a\x45stimateExitExactAmountOut\x12-.nibiru.dex.v1.QueryExitExactAmountOutRequest\x1a..nibiru.dex.v1.QueryExitExactAmountOutResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/dex/{poolId}/estimate/exit_exact_amount_outB+Z)github.com/NibiruChain/nibiru/x/dex/typesb\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYPOOLNUMBERREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolNumberRequest']
_QUERYPOOLNUMBERRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolNumberResponse']
_QUERYPOOLREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolRequest']
_QUERYPOOLRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolResponse']
_QUERYPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolsRequest']
_QUERYPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolsResponse']
_QUERYPOOLPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryPoolParamsRequest']
_QUERYPOOLPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryPoolParamsResponse']
_QUERYNUMPOOLSREQUEST = DESCRIPTOR.message_types_by_name['QueryNumPoolsRequest']
_QUERYNUMPOOLSRESPONSE = DESCRIPTOR.message_types_by_name['QueryNumPoolsResponse']
_QUERYTOTALLIQUIDITYREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalLiquidityRequest']
_QUERYTOTALLIQUIDITYRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalLiquidityResponse']
_QUERYTOTALPOOLLIQUIDITYREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalPoolLiquidityRequest']
_QUERYTOTALPOOLLIQUIDITYRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalPoolLiquidityResponse']
_QUERYTOTALSHARESREQUEST = DESCRIPTOR.message_types_by_name['QueryTotalSharesRequest']
_QUERYTOTALSHARESRESPONSE = DESCRIPTOR.message_types_by_name['QueryTotalSharesResponse']
_QUERYSPOTPRICEREQUEST = DESCRIPTOR.message_types_by_name['QuerySpotPriceRequest']
_QUERYSPOTPRICERESPONSE = DESCRIPTOR.message_types_by_name['QuerySpotPriceResponse']
_QUERYSWAPEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountInRequest']
_QUERYSWAPEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountInResponse']
_QUERYSWAPEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountOutRequest']
_QUERYSWAPEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QuerySwapExactAmountOutResponse']
_QUERYJOINEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountInRequest']
_QUERYJOINEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountInResponse']
_QUERYJOINEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountOutRequest']
_QUERYJOINEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QueryJoinExactAmountOutResponse']
_QUERYEXITEXACTAMOUNTINREQUEST = DESCRIPTOR.message_types_by_name['QueryExitExactAmountInRequest']
_QUERYEXITEXACTAMOUNTINRESPONSE = DESCRIPTOR.message_types_by_name['QueryExitExactAmountInResponse']
_QUERYEXITEXACTAMOUNTOUTREQUEST = DESCRIPTOR.message_types_by_name['QueryExitExactAmountOutRequest']
_QUERYEXITEXACTAMOUNTOUTRESPONSE = DESCRIPTOR.message_types_by_name['QueryExitExactAmountOutResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryPoolNumberRequest = _reflection.GeneratedProtocolMessageType('QueryPoolNumberRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLNUMBERREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolNumberRequest)
  })
_sym_db.RegisterMessage(QueryPoolNumberRequest)

QueryPoolNumberResponse = _reflection.GeneratedProtocolMessageType('QueryPoolNumberResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLNUMBERRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolNumberResponse)
  })
_sym_db.RegisterMessage(QueryPoolNumberResponse)

QueryPoolRequest = _reflection.GeneratedProtocolMessageType('QueryPoolRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolRequest)
  })
_sym_db.RegisterMessage(QueryPoolRequest)

QueryPoolResponse = _reflection.GeneratedProtocolMessageType('QueryPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolResponse)
  })
_sym_db.RegisterMessage(QueryPoolResponse)

QueryPoolsRequest = _reflection.GeneratedProtocolMessageType('QueryPoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolsRequest)
  })
_sym_db.RegisterMessage(QueryPoolsRequest)

QueryPoolsResponse = _reflection.GeneratedProtocolMessageType('QueryPoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolsResponse)
  })
_sym_db.RegisterMessage(QueryPoolsResponse)

QueryPoolParamsRequest = _reflection.GeneratedProtocolMessageType('QueryPoolParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLPARAMSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolParamsRequest)
  })
_sym_db.RegisterMessage(QueryPoolParamsRequest)

QueryPoolParamsResponse = _reflection.GeneratedProtocolMessageType('QueryPoolParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOOLPARAMSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryPoolParamsResponse)
  })
_sym_db.RegisterMessage(QueryPoolParamsResponse)

QueryNumPoolsRequest = _reflection.GeneratedProtocolMessageType('QueryNumPoolsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYNUMPOOLSREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryNumPoolsRequest)
  })
_sym_db.RegisterMessage(QueryNumPoolsRequest)

QueryNumPoolsResponse = _reflection.GeneratedProtocolMessageType('QueryNumPoolsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYNUMPOOLSRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryNumPoolsResponse)
  })
_sym_db.RegisterMessage(QueryNumPoolsResponse)

QueryTotalLiquidityRequest = _reflection.GeneratedProtocolMessageType('QueryTotalLiquidityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALLIQUIDITYREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalLiquidityRequest)
  })
_sym_db.RegisterMessage(QueryTotalLiquidityRequest)

QueryTotalLiquidityResponse = _reflection.GeneratedProtocolMessageType('QueryTotalLiquidityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALLIQUIDITYRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalLiquidityResponse)
  })
_sym_db.RegisterMessage(QueryTotalLiquidityResponse)

QueryTotalPoolLiquidityRequest = _reflection.GeneratedProtocolMessageType('QueryTotalPoolLiquidityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALPOOLLIQUIDITYREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalPoolLiquidityRequest)
  })
_sym_db.RegisterMessage(QueryTotalPoolLiquidityRequest)

QueryTotalPoolLiquidityResponse = _reflection.GeneratedProtocolMessageType('QueryTotalPoolLiquidityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALPOOLLIQUIDITYRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalPoolLiquidityResponse)
  })
_sym_db.RegisterMessage(QueryTotalPoolLiquidityResponse)

QueryTotalSharesRequest = _reflection.GeneratedProtocolMessageType('QueryTotalSharesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALSHARESREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalSharesRequest)
  })
_sym_db.RegisterMessage(QueryTotalSharesRequest)

QueryTotalSharesResponse = _reflection.GeneratedProtocolMessageType('QueryTotalSharesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOTALSHARESRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryTotalSharesResponse)
  })
_sym_db.RegisterMessage(QueryTotalSharesResponse)

QuerySpotPriceRequest = _reflection.GeneratedProtocolMessageType('QuerySpotPriceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTPRICEREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySpotPriceRequest)
  })
_sym_db.RegisterMessage(QuerySpotPriceRequest)

QuerySpotPriceResponse = _reflection.GeneratedProtocolMessageType('QuerySpotPriceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTPRICERESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySpotPriceResponse)
  })
_sym_db.RegisterMessage(QuerySpotPriceResponse)

QuerySwapExactAmountInRequest = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountInRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTINREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountInRequest)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountInRequest)

QuerySwapExactAmountInResponse = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountInResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTINRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountInResponse)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountInResponse)

QuerySwapExactAmountOutRequest = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTOUTREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountOutRequest)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountOutRequest)

QuerySwapExactAmountOutResponse = _reflection.GeneratedProtocolMessageType('QuerySwapExactAmountOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSWAPEXACTAMOUNTOUTRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QuerySwapExactAmountOutResponse)
  })
_sym_db.RegisterMessage(QuerySwapExactAmountOutResponse)

QueryJoinExactAmountInRequest = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountInRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTINREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountInRequest)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountInRequest)

QueryJoinExactAmountInResponse = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountInResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTINRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountInResponse)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountInResponse)

QueryJoinExactAmountOutRequest = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTOUTREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountOutRequest)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountOutRequest)

QueryJoinExactAmountOutResponse = _reflection.GeneratedProtocolMessageType('QueryJoinExactAmountOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYJOINEXACTAMOUNTOUTRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryJoinExactAmountOutResponse)
  })
_sym_db.RegisterMessage(QueryJoinExactAmountOutResponse)

QueryExitExactAmountInRequest = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountInRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTINREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountInRequest)
  })
_sym_db.RegisterMessage(QueryExitExactAmountInRequest)

QueryExitExactAmountInResponse = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountInResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTINRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountInResponse)
  })
_sym_db.RegisterMessage(QueryExitExactAmountInResponse)

QueryExitExactAmountOutRequest = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountOutRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTOUTREQUEST,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountOutRequest)
  })
_sym_db.RegisterMessage(QueryExitExactAmountOutRequest)

QueryExitExactAmountOutResponse = _reflection.GeneratedProtocolMessageType('QueryExitExactAmountOutResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXITEXACTAMOUNTOUTRESPONSE,
  '__module__' : 'dex.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.dex.v1.QueryExitExactAmountOutResponse)
  })
_sym_db.RegisterMessage(QueryExitExactAmountOutResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z)github.com/NibiruChain/nibiru/x/dex/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._options = None
  _QUERYTOTALPOOLLIQUIDITYRESPONSE.fields_by_name['liquidity']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"liquidity\"\310\336\037\000'
  _QUERYTOTALSHARESRESPONSE.fields_by_name['totalShares']._options = None
  _QUERYTOTALSHARESRESPONSE.fields_by_name['totalShares']._serialized_options = b'\362\336\037\023yaml:\"total_shares\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['tokenIn']._options = None
  _QUERYSWAPEXACTAMOUNTINREQUEST.fields_by_name['tokenIn']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['tokenOut']._options = None
  _QUERYSWAPEXACTAMOUNTINRESPONSE.fields_by_name['tokenOut']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['tokenOut']._options = None
  _QUERYSWAPEXACTAMOUNTOUTREQUEST.fields_by_name['tokenOut']._serialized_options = b'\362\336\037\020yaml:\"token_out\"\310\336\037\000'
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['tokenIn']._options = None
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE.fields_by_name['tokenIn']._serialized_options = b'\362\336\037\017yaml:\"token_in\"\310\336\037\000'
  _QUERYJOINEXACTAMOUNTINREQUEST.fields_by_name['tokensIn']._options = None
  _QUERYJOINEXACTAMOUNTINREQUEST.fields_by_name['tokensIn']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"tokens_in\"\310\336\037\000'
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['poolSharesOut']._options = None
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['poolSharesOut']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\026yaml:\"pool_shares_out\"\310\336\037\000'
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['remCoins']._options = None
  _QUERYJOINEXACTAMOUNTINRESPONSE.fields_by_name['remCoins']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\020yaml:\"rem_coins\"\310\336\037\000'
  _QUERYEXITEXACTAMOUNTINREQUEST.fields_by_name['poolSharesIn']._options = None
  _QUERYEXITEXACTAMOUNTINREQUEST.fields_by_name['poolSharesIn']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\362\336\037\025yaml:\"pool_shares_in\"\310\336\037\000'
  _QUERYEXITEXACTAMOUNTINRESPONSE.fields_by_name['tokensOut']._options = None
  _QUERYEXITEXACTAMOUNTINRESPONSE.fields_by_name['tokensOut']._serialized_options = b'\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins\362\336\037\021yaml:\"tokens_out\"\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\024\022\022/nibiru/dex/params'
  _QUERY.methods_by_name['PoolNumber']._options = None
  _QUERY.methods_by_name['PoolNumber']._serialized_options = b'\202\323\344\223\002\031\022\027/nibiru/dex/pool_number'
  _QUERY.methods_by_name['Pool']._options = None
  _QUERY.methods_by_name['Pool']._serialized_options = b'\202\323\344\223\002\022\022\020/nibiru/dex/pool'
  _QUERY.methods_by_name['Pools']._options = None
  _QUERY.methods_by_name['Pools']._serialized_options = b'\202\323\344\223\002\023\022\021/nibiru/dex/pools'
  _QUERY.methods_by_name['PoolParams']._options = None
  _QUERY.methods_by_name['PoolParams']._serialized_options = b'\202\323\344\223\002#\022!/nibiru/dex/pools/{poolId}/params'
  _QUERY.methods_by_name['NumPools']._options = None
  _QUERY.methods_by_name['NumPools']._serialized_options = b'\202\323\344\223\002\027\022\025/nibiru/dex/num_pools'
  _QUERY.methods_by_name['TotalLiquidity']._options = None
  _QUERY.methods_by_name['TotalLiquidity']._serialized_options = b'\202\323\344\223\002\035\022\033/nibiru/dex/total_liquidity'
  _QUERY.methods_by_name['TotalPoolLiquidity']._options = None
  _QUERY.methods_by_name['TotalPoolLiquidity']._serialized_options = b'\202\323\344\223\0021\022//nibiru/dex/pools/{poolId}/total_pool_liquidity'
  _QUERY.methods_by_name['TotalShares']._options = None
  _QUERY.methods_by_name['TotalShares']._serialized_options = b'\202\323\344\223\002)\022\'/nibiru/dex/pools/{poolId}/total_shares'
  _QUERY.methods_by_name['SpotPrice']._options = None
  _QUERY.methods_by_name['SpotPrice']._serialized_options = b'\202\323\344\223\002#\022!/nibiru/dex/pools/{poolId}/prices'
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountIn']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/dex/{poolId}/estimate/swap_exact_amount_in'
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateSwapExactAmountOut']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{poolId}/estimate/swap_exact_amount_out'
  _QUERY.methods_by_name['EstimateJoinExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateJoinExactAmountIn']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/dex/{poolId}/estimate/join_exact_amount_in'
  _QUERY.methods_by_name['EstimateJoinExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateJoinExactAmountOut']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{poolId}/estimate/join_exact_amount_out'
  _QUERY.methods_by_name['EstimateExitExactAmountIn']._options = None
  _QUERY.methods_by_name['EstimateExitExactAmountIn']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/dex/{poolId}/estimate/exit_exact_amount_in'
  _QUERY.methods_by_name['EstimateExitExactAmountOut']._options = None
  _QUERY.methods_by_name['EstimateExitExactAmountOut']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/dex/{poolId}/estimate/exit_exact_amount_out'
  _QUERYPARAMSREQUEST._serialized_start=205
  _QUERYPARAMSREQUEST._serialized_end=225
  _QUERYPARAMSRESPONSE._serialized_start=227
  _QUERYPARAMSRESPONSE._serialized_end=293
  _QUERYPOOLNUMBERREQUEST._serialized_start=295
  _QUERYPOOLNUMBERREQUEST._serialized_end=319
  _QUERYPOOLNUMBERRESPONSE._serialized_start=321
  _QUERYPOOLNUMBERRESPONSE._serialized_end=362
  _QUERYPOOLREQUEST._serialized_start=364
  _QUERYPOOLREQUEST._serialized_end=398
  _QUERYPOOLRESPONSE._serialized_start=400
  _QUERYPOOLRESPONSE._serialized_end=454
  _QUERYPOOLSREQUEST._serialized_start=456
  _QUERYPOOLSREQUEST._serialized_end=535
  _QUERYPOOLSRESPONSE._serialized_start=537
  _QUERYPOOLSRESPONSE._serialized_end=654
  _QUERYPOOLPARAMSREQUEST._serialized_start=656
  _QUERYPOOLPARAMSREQUEST._serialized_end=696
  _QUERYPOOLPARAMSRESPONSE._serialized_start=698
  _QUERYPOOLPARAMSRESPONSE._serialized_end=770
  _QUERYNUMPOOLSREQUEST._serialized_start=772
  _QUERYNUMPOOLSREQUEST._serialized_end=794
  _QUERYNUMPOOLSRESPONSE._serialized_start=796
  _QUERYNUMPOOLSRESPONSE._serialized_end=837
  _QUERYTOTALLIQUIDITYREQUEST._serialized_start=839
  _QUERYTOTALLIQUIDITYREQUEST._serialized_end=867
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_start=870
  _QUERYTOTALLIQUIDITYRESPONSE._serialized_end=1015
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_start=1017
  _QUERYTOTALPOOLLIQUIDITYREQUEST._serialized_end=1065
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_start=1068
  _QUERYTOTALPOOLLIQUIDITYRESPONSE._serialized_end=1217
  _QUERYTOTALSHARESREQUEST._serialized_start=1219
  _QUERYTOTALSHARESREQUEST._serialized_end=1260
  _QUERYTOTALSHARESRESPONSE._serialized_start=1262
  _QUERYTOTALSHARESRESPONSE._serialized_end=1365
  _QUERYSPOTPRICEREQUEST._serialized_start=1367
  _QUERYSPOTPRICEREQUEST._serialized_end=1451
  _QUERYSPOTPRICERESPONSE._serialized_start=1453
  _QUERYSPOTPRICERESPONSE._serialized_end=1496
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_start=1499
  _QUERYSWAPEXACTAMOUNTINREQUEST._serialized_end=1638
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_start=1640
  _QUERYSWAPEXACTAMOUNTINRESPONSE._serialized_end=1743
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_start=1746
  _QUERYSWAPEXACTAMOUNTOUTREQUEST._serialized_end=1887
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_start=1889
  _QUERYSWAPEXACTAMOUNTOUTRESPONSE._serialized_end=1991
  _QUERYJOINEXACTAMOUNTINREQUEST._serialized_start=1994
  _QUERYJOINEXACTAMOUNTINREQUEST._serialized_end=2156
  _QUERYJOINEXACTAMOUNTINRESPONSE._serialized_start=2159
  _QUERYJOINEXACTAMOUNTINRESPONSE._serialized_end=2403
  _QUERYJOINEXACTAMOUNTOUTREQUEST._serialized_start=2405
  _QUERYJOINEXACTAMOUNTOUTREQUEST._serialized_end=2453
  _QUERYJOINEXACTAMOUNTOUTRESPONSE._serialized_start=2455
  _QUERYJOINEXACTAMOUNTOUTRESPONSE._serialized_end=2488
  _QUERYEXITEXACTAMOUNTINREQUEST._serialized_start=2491
  _QUERYEXITEXACTAMOUNTINREQUEST._serialized_end=2633
  _QUERYEXITEXACTAMOUNTINRESPONSE._serialized_start=2636
  _QUERYEXITEXACTAMOUNTINRESPONSE._serialized_end=2785
  _QUERYEXITEXACTAMOUNTOUTREQUEST._serialized_start=2787
  _QUERYEXITEXACTAMOUNTOUTREQUEST._serialized_end=2835
  _QUERYEXITEXACTAMOUNTOUTRESPONSE._serialized_start=2837
  _QUERYEXITEXACTAMOUNTOUTRESPONSE._serialized_end=2870
  _QUERY._serialized_start=2873
  _QUERY._serialized_end=5284
# @@protoc_insertion_point(module_scope)
